Class: Playbook::PbAdvancedTable::TableBody
- Defined in:
- app/pb_kits/playbook/pb_advanced_table/table_body.rb
Constant Summary
Constants included from Playbook::PositionPropsCss
Playbook::PositionPropsCss::POSITION_VALUES
Instance Attribute Summary
Attributes included from Playbook::Props
Instance Method Summary collapse
- #cell_accessors_length(col_defs) ⇒ Object
- #classname ⇒ Object
- #flatten_columns(columns) ⇒ Object
- #pinned_cell_class(index) ⇒ Object
-
#render_inline_loading_row(column_count, depth, data_attributes) ⇒ Object
3 helper methods for inline row loading.
- #render_row_and_children(row, column_definitions, current_depth, first_parent_child, ancestor_ids = [], top_parent_id = nil, additional_classes: "", table_data_attributes: {}, immediate_parent_row_id: nil) ⇒ Object
- #row_children_for(row) ⇒ Object
Methods inherited from KitBase
#combined_html_options, #global_inline_props, #object, #pb_content_tag, #react_component
Methods included from MaxHeight
included, #max_height_options, #max_height_props, #max_height_values
Methods included from MinHeight
included, #min_height_options, #min_height_props, #min_height_values
Methods included from Height
#height_options, #height_props, #height_values, included
Methods included from VerticalAlign
included, #vertical_align_options, #vertical_align_props, #vertical_align_values
Methods included from Bottom
#bottom_options, #bottom_values, included
Methods included from Playbook::PositionPropsCss
Methods included from Right
included, #right_options, #right_values
Methods included from Top
included, #top_options, #top_values
Methods included from Left
included, #left_options, #left_values
Methods included from Truncate
included, #truncate_options, #truncate_props, #truncate_values
Methods included from Overflow
included, #overflow_options, #overflow_props, #overflow_values
Methods included from TextAlign
included, #text_align_options, #text_align_props, #text_align_values
Methods included from BorderRadius
#border_radius_options, #border_radius_props, #border_radius_values, included
Methods included from Hover
#hover_attributes, #hover_background_values, #hover_color_values, #hover_options, #hover_props, #hover_scale_values, #hover_shadow_values, #hover_underline_values, #hover_values, #hover_visible_values, included
Methods included from Playbook::Position
included, #position_options, #position_values
Methods included from Order
included, #order_options, #order_props, #order_values
Methods included from FlexShrink
#flex_shrink_options, #flex_shrink_props, #flex_shrink_values, included
Methods included from FlexGrow
#flex_grow_options, #flex_grow_props, #flex_grow_values, included
Methods included from Flex
#flex_options, #flex_props, #flex_values, included
Methods included from AlignSelf
#align_self_options, #align_self_props, #align_self_values, included
Methods included from AlignContent
#align_content_options, #align_content_props, #align_content_values, included
Methods included from AlignItems
#align_items_options, #align_items_props, #align_items_values, included
Methods included from JustifySelf
included, #justify_self_options, #justify_self_props, #justify_self_values
Methods included from JustifyContent
included, #justify_content_options, #justify_content_props, #justify_content_values
Methods included from FlexWrap
#flex_wrap_options, #flex_wrap_props, #flex_wrap_values, included
Methods included from FlexDirection
#flex_direction_options, #flex_direction_props, #flex_direction_values, included
Methods included from Cursor
#cursor_options, #cursor_props, #cursor_values, included
Methods included from Display
#display_options, #display_props, #display_size_values, #display_values, included
Methods included from LineHeight
included, #line_height_options, #line_height_props, #line_height_values
Methods included from Shadow
included, #shadow_options, #shadow_props, #shadow_values
Methods included from NumberSpacing
included, #number_spacing_options, #number_spacing_values
Methods included from ZIndex
included, #screen_size_values, #z_index_options, #z_index_props, #z_index_values
Methods included from Spacing
#break_method_values, #column_gap_options, #column_gap_props, #filter_classname, #gap_options, #gap_props, #gap_values, included, #max_width_options, #max_width_props, #max_width_values, #min_width_options, #min_width_props, #min_width_values, #row_gap_options, #row_gap_props, #screen_size_values, #spacing_options, #spacing_props, #spacing_values, #width_options, #width_props, #width_values
Methods included from Classnames
#generate_classname, #generate_classname_without_spacing, included
Methods included from Playbook::Props
Methods included from Playbook::PbKitHelper
#deprecated_kit_warning, #pb_rails
Methods included from Playbook::PbFormsHelper
Instance Method Details
#cell_accessors_length(col_defs) ⇒ Object
145 146 147 148 149 150 151 152 153 154 155 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 145 def cell_accessors_length(col_defs) first_col = col_defs.first return 0 unless first_col accessors = if first_col.respond_to?(:cellAccessors) first_col.cellAccessors elsif first_col.respond_to?(:[]) first_col[:cellAccessors] || first_col["cellAccessors"] end accessors&.length || 0 end |
#classname ⇒ Object
113 114 115 116 117 118 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 113 def classname additional_classes = [] additional_classes << "advanced-table-responsive-#{responsive} pinned-left" if responsive == "scroll" additional_classes << "selectable-rows-enabled" if selectable_rows && enable_toggle_expansion == "none" generate_classname("pb_advanced_table_body", *additional_classes, separator: " ") end |
#flatten_columns(columns) ⇒ Object
31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 31 def flatten_columns(columns) columns.flat_map do |col| if col[:columns] flatten_columns(col[:columns]) elsif col[:accessor].present? if has_grouped_headers? col.merge(is_last_in_group: last_in_group?(columns, col)) else col end end end.compact end |
#pinned_cell_class(index) ⇒ Object
120 121 122 123 124 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 120 def pinned_cell_class(index) return "pinned-left" if index.zero? && responsive == "scroll" "" end |
#render_inline_loading_row(column_count, depth, data_attributes) ⇒ Object
3 helper methods for inline row loading
127 128 129 130 131 132 133 134 135 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 127 def render_inline_loading_row(column_count, depth, data_attributes) padding_left = depth.zero? ? "0.5em" : "#{(depth + 1) * 2}em" content_tag(:tr, class: "toggle-content inline-loading-row", data: data_attributes) do content_tag(:td, colspan: column_count, style: "padding-left: #{padding_left}") do pb_rails("loading_inline") end end end |
#render_row_and_children(row, column_definitions, current_depth, first_parent_child, ancestor_ids = [], top_parent_id = nil, additional_classes: "", table_data_attributes: {}, immediate_parent_row_id: nil) ⇒ Object
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 45 def render_row_and_children(row, column_definitions, current_depth, first_parent_child, ancestor_ids = [], top_parent_id = nil, additional_classes: "", table_data_attributes: {}, immediate_parent_row_id: nil) top_parent_id ||= row.object_id new_ancestor_ids = ancestor_ids + [row.object_id] leaf_columns = flatten_columns(column_definitions) output = ActiveSupport::SafeBuffer.new is_first_child_of_subrow = current_depth.positive? && first_parent_child && subrow_headers[current_depth - 1].present? last_row = subrow_headers.length == current_depth subrow_ancestor_ids = ancestor_ids + ["#{row.object_id}sr"] subrow_data_attributes = { advanced_table_content: subrow_ancestor_ids.join("-"), row_depth: current_depth, row_parent: "#{table_id}_#{ancestor_ids.last}", } # Subrow header if applicable output << pb_rails("advanced_table/table_subrow_header", props: { row: row, column_definitions: leaf_columns, depth: current_depth, subrow_header: subrow_headers[current_depth - 1], collapsible_trail: collapsible_trail, classname: "toggle-content", responsive: responsive, subrow_data_attributes: subrow_data_attributes, last_row: last_row, immediate_parent_row_id: immediate_parent_row_id }) if is_first_child_of_subrow && enable_toggle_expansion == "all" current_data_attributes = if current_depth.zero? { row_depth: 0, advanced_table_content: row.object_id.to_s, row_parent: nil, } else table_data_attributes end # Additional class and data attributes needed for toggle logic output << pb_rails("advanced_table/table_row", props: { table_id: table_id, row: row, column_definitions: leaf_columns, depth: current_depth, collapsible_trail: collapsible_trail, classname: additional_classes, table_data_attributes: current_data_attributes, responsive: responsive, loading: loading, selectable_rows: selectable_rows, row_id: row[:id], enable_toggle_expansion: enable_toggle_expansion, row_styling: row_styling, last_row: last_row, immediate_parent_row_id: immediate_parent_row_id, inline_row_loading: inline_row_loading }) # Render inline loading row when inline_row_loading is enabled and row has empty children if inline_row_loading children = row_children_for(row) if children.is_a?(::Array) && children.empty? max_depth = cell_accessors_length(column_definitions) if current_depth < max_depth loading_row_data_attributes = { advanced_table_content: "#{new_ancestor_ids.join('-')}-loading", row_depth: current_depth + 1, row_parent: "#{table_id}_#{row.object_id}", inline_loading_row: true, } output << render_inline_loading_row(leaf_columns.length, current_depth, loading_row_data_attributes) end end end if row[:children].present? row[:children].each do |child_row| is_first_child = row[:children].first == child_row immediate_parent_id = row.object_id data_content = new_ancestor_ids.join("-") + "-#{child_row.object_id}" child_data_attributes = { top_parent: "#{table_id}_#{top_parent_id}", row_depth: current_depth + 1, row_parent: "#{table_id}_#{immediate_parent_id}", advanced_table_content: data_content, } output << render_row_and_children(child_row, column_definitions, current_depth + 1, is_first_child, new_ancestor_ids, top_parent_id, additional_classes: "toggle-content", table_data_attributes: child_data_attributes, immediate_parent_row_id: row[:id]) end end output end |
#row_children_for(row) ⇒ Object
137 138 139 140 141 142 143 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 137 def row_children_for(row) if row.respond_to?(:children) row.children elsif row.respond_to?(:[]) row[:children] || row["children"] end end |