Class: Playbook::PbAdvancedTable::TableBody
- Defined in:
- app/pb_kits/playbook/pb_advanced_table/table_body.rb
Constant Summary
Constants included from Playbook::PositionPropsCss
Playbook::PositionPropsCss::POSITION_VALUES
Instance Attribute Summary
Attributes included from Playbook::Props
Instance Method Summary collapse
- #cell_accessors_length(col_defs) ⇒ Object
- #classname ⇒ Object
- #collect_row_and_descendant_ids(row, set) ⇒ Object
- #find_row_by_id(data, id, depth: 0, ancestor_ids: [], parent_row: nil) ⇒ Object
- #flatten_columns(columns) ⇒ Object
- #has_pinned_rows? ⇒ Boolean
- #pinned_cell_class(index) ⇒ Object
- #pinned_ids_set ⇒ Object
- #pinned_root_initial_data_attributes(root_info) ⇒ Object
- #pinned_root_rows ⇒ Object
- #pinned_top_ids ⇒ Object
-
#render_inline_loading_row(column_count, depth, data_attributes) ⇒ Object
3 helper methods for inline row loading.
- #render_row_and_children(row, column_definitions, current_depth, first_parent_child, ancestor_ids = [], top_parent_id = nil, additional_classes: "", table_data_attributes: {}, immediate_parent_row_id: nil, is_pinned_row: false, pinned_index: nil, skip_pinned_ids: nil, initial_table_data_attributes: nil) ⇒ Object
- #row_children_for(row) ⇒ Object
- #row_id_for(row) ⇒ Object
Methods inherited from KitBase
#combined_html_options, #global_inline_props, #object, #pb_content_tag, #react_component
Methods included from MaxHeight
included, #max_height_options, #max_height_props, #max_height_values
Methods included from MinHeight
included, #min_height_options, #min_height_props, #min_height_values
Methods included from Height
#height_options, #height_props, #height_values, included
Methods included from VerticalAlign
included, #vertical_align_options, #vertical_align_props, #vertical_align_values
Methods included from Bottom
#bottom_options, #bottom_values, included
Methods included from Playbook::PositionPropsCss
Methods included from Right
included, #right_options, #right_values
Methods included from Top
included, #top_options, #top_values
Methods included from Left
included, #left_options, #left_values
Methods included from Truncate
included, #truncate_options, #truncate_props, #truncate_values
Methods included from Overflow
included, #overflow_options, #overflow_props, #overflow_values
Methods included from TextAlign
included, #text_align_options, #text_align_props, #text_align_values
Methods included from BorderRadius
#border_radius_options, #border_radius_props, #border_radius_values, included
Methods included from Hover
#hover_attributes, #hover_background_values, #hover_color_values, #hover_options, #hover_props, #hover_scale_values, #hover_shadow_values, #hover_underline_values, #hover_values, #hover_visible_values, included
Methods included from Playbook::Position
included, #position_options, #position_values
Methods included from Order
included, #order_options, #order_props, #order_values
Methods included from FlexShrink
#flex_shrink_options, #flex_shrink_props, #flex_shrink_values, included
Methods included from FlexGrow
#flex_grow_options, #flex_grow_props, #flex_grow_values, included
Methods included from Flex
#flex_options, #flex_props, #flex_values, included
Methods included from AlignSelf
#align_self_options, #align_self_props, #align_self_values, included
Methods included from AlignContent
#align_content_options, #align_content_props, #align_content_values, included
Methods included from AlignItems
#align_items_options, #align_items_props, #align_items_values, included
Methods included from JustifySelf
included, #justify_self_options, #justify_self_props, #justify_self_values
Methods included from JustifyContent
included, #justify_content_options, #justify_content_props, #justify_content_values
Methods included from FlexWrap
#flex_wrap_options, #flex_wrap_props, #flex_wrap_values, included
Methods included from FlexDirection
#flex_direction_options, #flex_direction_props, #flex_direction_values, included
Methods included from Cursor
#cursor_options, #cursor_props, #cursor_values, included
Methods included from Display
#display_options, #display_props, #display_size_values, #display_values, included
Methods included from LineHeight
included, #line_height_options, #line_height_props, #line_height_values
Methods included from Shadow
included, #shadow_options, #shadow_props, #shadow_values
Methods included from NumberSpacing
included, #number_spacing_options, #number_spacing_values
Methods included from ZIndex
included, #screen_size_values, #z_index_options, #z_index_props, #z_index_values
Methods included from Spacing
#break_method_values, #column_gap_options, #column_gap_props, #filter_classname, #gap_options, #gap_props, #gap_values, included, #max_width_options, #max_width_props, #max_width_values, #min_width_options, #min_width_props, #min_width_values, #row_gap_options, #row_gap_props, #screen_size_values, #spacing_options, #spacing_props, #spacing_values, #width_options, #width_props, #width_values
Methods included from Classnames
#generate_classname, #generate_classname_without_spacing, included
Methods included from Playbook::Props
Methods included from Playbook::PbKitHelper
#deprecated_kit_warning, #pb_rails
Methods included from Playbook::PbFormsHelper
Instance Method Details
#cell_accessors_length(col_defs) ⇒ Object
241 242 243 244 245 246 247 248 249 250 251 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 241 def cell_accessors_length(col_defs) first_col = col_defs.first return 0 unless first_col accessors = if first_col.respond_to?(:cellAccessors) first_col.cellAccessors elsif first_col.respond_to?(:[]) first_col[:cellAccessors] || first_col["cellAccessors"] end accessors&.length || 0 end |
#classname ⇒ Object
146 147 148 149 150 151 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 146 def classname additional_classes = [] additional_classes << "advanced-table-responsive-#{responsive} pinned-left" if responsive == "scroll" additional_classes << "selectable-rows-enabled" if selectable_rows && enable_toggle_expansion == "none" generate_classname("pb_advanced_table_body", *additional_classes, separator: " ") end |
#collect_row_and_descendant_ids(row, set) ⇒ Object
201 202 203 204 205 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 201 def collect_row_and_descendant_ids(row, set) id = row_id_for(row) set.add(id.to_s) if id row_children_for(row)&.each { |child| collect_row_and_descendant_ids(child, set) } end |
#find_row_by_id(data, id, depth: 0, ancestor_ids: [], parent_row: nil) ⇒ Object
207 208 209 210 211 212 213 214 215 216 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 207 def find_row_by_id(data, id, depth: 0, ancestor_ids: [], parent_row: nil) id_str = id.to_s Array(data).each do |row| return { row: row, depth: depth, ancestor_ids: ancestor_ids, parent_row: parent_row } if row_id_for(row).to_s == id_str found = find_row_by_id(row_children_for(row), id_str, depth: depth + 1, ancestor_ids: ancestor_ids + [row.object_id], parent_row: row) return found if found end nil end |
#flatten_columns(columns) ⇒ Object
33 34 35 36 37 38 39 40 41 42 43 44 45 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 33 def flatten_columns(columns) columns.flat_map do |col| if col[:columns] flatten_columns(col[:columns]) elsif col[:accessor].present? if has_grouped_headers? col.merge(is_last_in_group: last_in_group?(columns, col)) else col end end end.compact end |
#has_pinned_rows? ⇒ Boolean
224 225 226 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 224 def has_pinned_rows? pinned_root_rows.any? end |
#pinned_cell_class(index) ⇒ Object
153 154 155 156 157 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 153 def pinned_cell_class(index) return "pinned-left" if index.zero? && responsive == "scroll" "" end |
#pinned_ids_set ⇒ Object
191 192 193 194 195 196 197 198 199 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 191 def pinned_ids_set return Set.new if pinned_top_ids.blank? set = Set.new pinned_root_rows.each do |root| collect_row_and_descendant_ids(root[:row], set) end set end |
#pinned_root_initial_data_attributes(root_info) ⇒ Object
228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 228 def pinned_root_initial_data_attributes(root_info) return {} if root_info[:depth].to_i.zero? anc = root_info[:ancestor_ids] || [] content = (anc + [root_info[:row].object_id]).join("-") { top_parent: "#{table_id}_#{anc.first}", row_depth: root_info[:depth], row_parent: "#{table_id}_#{anc.last}", advanced_table_content: content, } end |
#pinned_root_rows ⇒ Object
218 219 220 221 222 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 218 def pinned_root_rows return [] if pinned_top_ids.blank? pinned_top_ids.filter_map { |id| find_row_by_id(table_data, id) } end |
#pinned_top_ids ⇒ Object
184 185 186 187 188 189 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 184 def pinned_top_ids return [] if pinned_rows.nil? || !pinned_rows.respond_to?(:[]) top = pinned_rows["top"] || pinned_rows[:top] Array(top).map(&:to_s) end |
#render_inline_loading_row(column_count, depth, data_attributes) ⇒ Object
3 helper methods for inline row loading
160 161 162 163 164 165 166 167 168 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 160 def render_inline_loading_row(column_count, depth, data_attributes) padding_left = depth.zero? ? "0.5em" : "#{(depth + 1) * 2}em" content_tag(:tr, class: "toggle-content inline-loading-row", data: data_attributes) do content_tag(:td, colspan: column_count, style: "padding-left: #{padding_left}") do pb_rails("loading_inline") end end end |
#render_row_and_children(row, column_definitions, current_depth, first_parent_child, ancestor_ids = [], top_parent_id = nil, additional_classes: "", table_data_attributes: {}, immediate_parent_row_id: nil, is_pinned_row: false, pinned_index: nil, skip_pinned_ids: nil, initial_table_data_attributes: nil) ⇒ Object
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 47 def render_row_and_children(row, column_definitions, current_depth, first_parent_child, ancestor_ids = [], top_parent_id = nil, additional_classes: "", table_data_attributes: {}, immediate_parent_row_id: nil, is_pinned_row: false, pinned_index: nil, skip_pinned_ids: nil, initial_table_data_attributes: nil) if skip_pinned_ids && row_id_for(row) && skip_pinned_ids.include?(row_id_for(row).to_s) return is_pinned_row ? [ActiveSupport::SafeBuffer.new, pinned_index] : ActiveSupport::SafeBuffer.new end top_parent_id ||= row.object_id new_ancestor_ids = ancestor_ids + [row.object_id] leaf_columns = flatten_columns(column_definitions || []) output = ActiveSupport::SafeBuffer.new subrow_headers_arr = subrow_headers || [] is_first_child_of_subrow = current_depth.positive? && first_parent_child && subrow_headers_arr[current_depth - 1].present? last_row = subrow_headers_arr.length == current_depth next_pinned_index = pinned_index subrow_ancestor_ids = ancestor_ids + ["#{row.object_id}sr"] subrow_data_attributes = { advanced_table_content: subrow_ancestor_ids.join("-"), row_depth: current_depth, row_parent: "#{table_id}_#{ancestor_ids.last}", } # Subrow header if applicable if is_first_child_of_subrow && enable_toggle_expansion == "all" subrow_props = { row: row, column_definitions: leaf_columns, depth: current_depth, subrow_header: subrow_headers_arr[current_depth - 1], collapsible_trail: collapsible_trail, classname: "toggle-content", responsive: responsive, subrow_data_attributes: subrow_data_attributes, last_row: last_row, immediate_parent_row_id: immediate_parent_row_id } if is_pinned_row && next_pinned_index subrow_props[:is_pinned_row] = true subrow_props[:pinned_index] = next_pinned_index next_pinned_index += 1 end output << pb_rails("advanced_table/table_subrow_header", props: subrow_props) end current_data_attributes = if current_depth.zero? { row_depth: 0, advanced_table_content: row.object_id.to_s, row_parent: nil, } else initial_table_data_attributes || table_data_attributes end # Additional class and data attributes needed for toggle logic row_props = { table_id: table_id, row: row, column_definitions: leaf_columns, depth: current_depth, collapsible_trail: collapsible_trail, classname: additional_classes, table_data_attributes: current_data_attributes, responsive: responsive, loading: loading, selectable_rows: selectable_rows, row_id: row[:id], enable_toggle_expansion: enable_toggle_expansion, row_styling: row_styling, last_row: last_row, immediate_parent_row_id: immediate_parent_row_id, inline_row_loading: inline_row_loading } if is_pinned_row && next_pinned_index row_props[:is_pinned_row] = true row_props[:pinned_index] = next_pinned_index next_pinned_index += 1 end output << pb_rails("advanced_table/table_row", props: row_props) # Render inline loading row when inline_row_loading is enabled and row has empty children if inline_row_loading children = row_children_for(row) if children.is_a?(::Array) && children.empty? max_depth = cell_accessors_length(column_definitions) if current_depth < max_depth loading_row_data_attributes = { advanced_table_content: "#{new_ancestor_ids.join('-')}-loading", row_depth: current_depth + 1, row_parent: "#{table_id}_#{row.object_id}", inline_loading_row: true, } output << render_inline_loading_row(leaf_columns.length, current_depth, loading_row_data_attributes) end end end if row[:children].present? row[:children].each do |child_row| is_first_child = row[:children].first == child_row immediate_parent_id = row.object_id data_content = new_ancestor_ids.join("-") + "-#{child_row.object_id}" child_data_attributes = { top_parent: "#{table_id}_#{top_parent_id}", row_depth: current_depth + 1, row_parent: "#{table_id}_#{immediate_parent_id}", advanced_table_content: data_content, } child_opts = { additional_classes: "toggle-content", table_data_attributes: child_data_attributes, immediate_parent_row_id: row[:id] } child_opts[:is_pinned_row] = is_pinned_row child_opts[:pinned_index] = next_pinned_index if is_pinned_row child_opts[:skip_pinned_ids] = skip_pinned_ids if skip_pinned_ids child_output, next_pinned_index = render_row_and_children(child_row, column_definitions, current_depth + 1, is_first_child, new_ancestor_ids, top_parent_id, **child_opts) output << child_output end end if is_pinned_row [output, next_pinned_index] else output end end |
#row_children_for(row) ⇒ Object
170 171 172 173 174 175 176 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 170 def row_children_for(row) if row.respond_to?(:children) row.children elsif row.respond_to?(:[]) row[:children] || row["children"] end end |
#row_id_for(row) ⇒ Object
178 179 180 181 182 |
# File 'app/pb_kits/playbook/pb_advanced_table/table_body.rb', line 178 def row_id_for(row) return nil if row.nil? row[:id] || row["id"] end |