Module: Playbook::PbDocHelper

Defined in:
lib/playbook/pb_doc_helper.rb

Instance Method Summary collapse

Instance Method Details

#aggregate_kitsObject



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/playbook/pb_doc_helper.rb', line 54

def aggregate_kits
  all_kits = []

  YAML.load_file(Playbook::Engine.root.join("dist/menu.yml"))["kits"].each do |kit|
    kit_name = kit["name"]
    components = kit["components"].map { |c| c["name"] }

    all_kits << if components.size == 1
                  components.first
                else
                  { kit_name => components }
                end
  end

  all_kits
end

#get_kits(type = "rails") ⇒ Object



45
46
47
48
49
50
51
52
# File 'lib/playbook/pb_doc_helper.rb', line 45

def get_kits(type = "rails")
  kits = YAML.load_file(Playbook::Engine.root.join("dist/menu.yml")) || []

  # Filter kits that have at least one component compatible with the type
  kits["kits"].select do |kit|
    kit["components"].any? { |component| component["platforms"].include?(type) }
  end
end

#pb_kit(kit: "", type: "rails", show_code: true, limit_examples: false, dark_mode: false) ⇒ Object



9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
# File 'lib/playbook/pb_doc_helper.rb', line 9

def pb_kit(kit: "", type: "rails", show_code: true, limit_examples: false, dark_mode: false)
  unless type == "swift"
    examples = pb_doc_kit_examples(kit, type)
    examples = examples.first(1) if limit_examples
    examples.map do |example|
      pb_rails "docs/kit_example", props: {
        kit: kit,
        example_title: example.values.first,
        example_key: example.keys.first,
        show_code: show_code,
        type: type,
        dark: dark_mode,
      }
    end.join.yield_self(&method(:raw))
  end
end

#pb_kit_title(title) ⇒ Object



5
6
7
# File 'lib/playbook/pb_doc_helper.rb', line 5

def pb_kit_title(title)
  title.remove("pb_").titleize.tr("_", " ")
end

#pb_kits(type: "rails", limit_examples: false, dark_mode: false) ⇒ Object

Deal with lists of kits, used in Playbook doc and Externally



27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
# File 'lib/playbook/pb_doc_helper.rb', line 27

def pb_kits(type: "rails", limit_examples: false, dark_mode: false)
  kits = get_kits(type)

  # Initialize an empty string to store the rendered HTML
  rendered_html = ""

  # Iterate through the filtered kits and render their child components
  kits.each do |kit|
    kit["components"].each do |component|
      # Check if the component is compatible with the specified type
      rendered_html += render_pb_doc_kit(component["name"], type, limit_examples, true, dark_mode) if component["platforms"].include?(type)
    end
  end

  # Return the rendered HTML as safe HTML
  rendered_html.html_safe
end

#render_pb_doc_kit(kit_name, type, limit_examples, code = true, dark_mode = false) ⇒ Object

rubocop:disable Style/OptionalBooleanParameter



72
73
74
75
76
77
# File 'lib/playbook/pb_doc_helper.rb', line 72

def render_pb_doc_kit(kit_name, type, limit_examples, code = true, dark_mode = false)
  title = pb_doc_render_clickable_title(kit_name, type)
  ui = raw("<div class='pb--docItem-ui'>
      #{pb_kit(kit: kit_name, type: type, show_code: code, limit_examples: limit_examples, dark_mode: dark_mode)}</div>")
  title + ui
end