Class: Playbook::PbPbLineGraph::PbLineGraph
- Defined in:
- app/pb_kits/playbook/pb_pb_line_graph/pb_line_graph.rb
Constant Summary
Constants inherited from KitBase
Constants included from MaxHeight
Constants included from MinHeight
Constants included from Height
Constants included from VerticalAlign
VerticalAlign::SCREEN_SIZES, VerticalAlign::VERTICAL_ALIGN_VALUES
Constants included from Bottom
Constants included from Playbook::PositionPropsCss
Playbook::PositionPropsCss::POSITION_VALUES
Constants included from Right
Constants included from Top
Constants included from Left
Constants included from Truncate
Constants included from Overflow
Constants included from TextAlign
TextAlign::SCREEN_SIZES, TextAlign::TEXT_ALIGN_VALUES
Constants included from BorderRadius
BorderRadius::BORDER_RADIUS_VALUES
Constants included from Hover
Hover::HOVER_ATTRIBUTES, Hover::HOVER_BACKGROUND_VALUES, Hover::HOVER_COLOR_VALUES, Hover::HOVER_SCALE_VALUES, Hover::HOVER_SHADOW_VALUES, Hover::HOVER_UNDERLINE_VALUES, Hover::HOVER_VISIBLE_VALUES
Constants included from Playbook::Position
Playbook::Position::POSITION_VALUES
Constants included from Order
Order::ORDER_VALUES, Order::SCREEN_SIZES
Constants included from FlexShrink
FlexShrink::FLEX_SHRINK_VALUES, FlexShrink::SCREEN_SIZES
Constants included from FlexGrow
FlexGrow::FLEX_GROW_VALUES, FlexGrow::SCREEN_SIZES
Constants included from Flex
Flex::FLEX_VALUES, Flex::SCREEN_SIZES
Constants included from AlignSelf
AlignSelf::ALIGN_SELF_VALUES, AlignSelf::SCREEN_SIZES
Constants included from AlignContent
AlignContent::ALIGN_CONTENT_VALUES, AlignContent::SCREEN_SIZES
Constants included from AlignItems
AlignItems::ALIGN_ITEMS_VALUES, AlignItems::SCREEN_SIZES
Constants included from JustifySelf
JustifySelf::JUSTIFY_SELF_VALUES, JustifySelf::SCREEN_SIZES
Constants included from JustifyContent
JustifyContent::JUSTIFY_CONTENT_VALUES, JustifyContent::SCREEN_SIZES
Constants included from FlexWrap
FlexWrap::FLEX_WRAP_VALUES, FlexWrap::SCREEN_SIZES
Constants included from FlexDirection
FlexDirection::FLEX_DIRECTION_VALUES, FlexDirection::SCREEN_SIZES
Constants included from Cursor
Constants included from Display
Display::DISPLAY_SIZE_VALUES, Display::DISPLAY_VALUES
Constants included from LineHeight
LineHeight::LINE_HEIGHT_VALUES
Constants included from Shadow
Constants included from NumberSpacing
NumberSpacing::NUMBER_SPACING_VALUES
Constants included from ZIndex
ZIndex::SCREEN_SIZES, ZIndex::Z_INDEX_VALUES
Constants included from Spacing
Spacing::BREAK_METHOD_VALUES, Spacing::GAP_VALUES, Spacing::MAX_WIDTH_VALUES, Spacing::MIN_WIDTH_VALUES, Spacing::SCREEN_SIZES, Spacing::SCREEN_SIZE_VALUES, Spacing::SPACING_HASH_SKIP_KEYS, Spacing::SPACING_PROP_MAP, Spacing::SPACING_VALUES, Spacing::WIDTH_VALUES
Instance Attribute Summary
Attributes included from Playbook::Props
Instance Method Summary collapse
Methods inherited from KitBase
#combined_html_options, #global_inline_props, #object, #pb_content_tag, #react_component
Methods included from MaxHeight
included, #max_height_options, #max_height_props, #max_height_values
Methods included from MinHeight
included, #min_height_options, #min_height_props, #min_height_values
Methods included from Height
#height_options, #height_props, #height_values, included
Methods included from VerticalAlign
included, #vertical_align_options, #vertical_align_props, #vertical_align_values
Methods included from Bottom
#bottom_options, #bottom_values, included
Methods included from Playbook::PositionPropsCss
Methods included from Right
included, #right_options, #right_values
Methods included from Top
included, #top_options, #top_values
Methods included from Left
included, #left_options, #left_values
Methods included from Truncate
included, #truncate_options, #truncate_props, #truncate_values
Methods included from Overflow
included, #overflow_options, #overflow_props, #overflow_values
Methods included from TextAlign
included, #text_align_options, #text_align_props, #text_align_values
Methods included from BorderRadius
#border_radius_options, #border_radius_props, #border_radius_values, included
Methods included from Hover
#hover_attributes, #hover_background_values, #hover_color_values, #hover_options, #hover_props, #hover_scale_values, #hover_shadow_values, #hover_underline_values, #hover_values, #hover_visible_values, included
Methods included from Playbook::Position
included, #position_options, #position_values
Methods included from Order
included, #order_options, #order_props, #order_values
Methods included from FlexShrink
#flex_shrink_options, #flex_shrink_props, #flex_shrink_values, included
Methods included from FlexGrow
#flex_grow_options, #flex_grow_props, #flex_grow_values, included
Methods included from Flex
#flex_options, #flex_props, #flex_values, included
Methods included from AlignSelf
#align_self_options, #align_self_props, #align_self_values, included
Methods included from AlignContent
#align_content_options, #align_content_props, #align_content_values, included
Methods included from AlignItems
#align_items_options, #align_items_props, #align_items_values, included
Methods included from JustifySelf
included, #justify_self_options, #justify_self_props, #justify_self_values
Methods included from JustifyContent
included, #justify_content_options, #justify_content_props, #justify_content_values
Methods included from FlexWrap
#flex_wrap_options, #flex_wrap_props, #flex_wrap_values, included
Methods included from FlexDirection
#flex_direction_options, #flex_direction_props, #flex_direction_values, included
Methods included from Cursor
#cursor_options, #cursor_props, #cursor_values, included
Methods included from Display
#display_options, #display_props, #display_size_values, #display_values, included
Methods included from LineHeight
included, #line_height_options, #line_height_props, #line_height_values
Methods included from Shadow
included, #shadow_options, #shadow_props, #shadow_values
Methods included from NumberSpacing
included, #number_spacing_options, #number_spacing_values
Methods included from ZIndex
included, #screen_size_values, #z_index_options, #z_index_props, #z_index_values
Methods included from Spacing
#break_method_values, #column_gap_options, #column_gap_props, #filter_classname, #gap_options, #gap_props, #gap_values, included, #max_width_options, #max_width_props, #max_width_values, #min_width_options, #min_width_props, #min_width_values, #row_gap_options, #row_gap_props, #screen_size_values, #spacing_options, #spacing_props, #spacing_values, #width_options, #width_props, #width_values
Methods included from Classnames
#dark_props, #generate_classname, #generate_classname_without_spacing, included
Methods included from Playbook::Props
Methods included from Playbook::PbKitHelper
#deprecated_kit_warning, #pb_rails
Methods included from Playbook::PbFormsHelper
Instance Method Details
#classname ⇒ Object
17 18 19 20 21 22 |
# File 'app/pb_kits/playbook/pb_pb_line_graph/pb_line_graph.rb', line 17 def classname # Highcharts react needs classname attached to the container div, # we pass an empty string here to avoid conflicts, classname is built in the TSX # We still need generate_classnames to retain ability to pass in custom classnames or global props generate_classname("") end |
#react_props ⇒ Object
8 9 10 11 12 13 14 15 |
# File 'app/pb_kits/playbook/pb_pb_line_graph/pb_line_graph.rb', line 8 def react_props { className: classname, data: data, options: , id: id, } end |